MaskPainterController class
Controller that manages all state for MaskPainterWidget
- Inheritance
-
- Object
- ChangeNotifier
- MaskPainterController
Constructors
Properties
- backgroundColor → Color
-
no setter
- backgroundImageUI → Image?
-
no setter
- brushSize → double
-
no setter
- canRedo → bool
-
no setter
- canUndo → bool
-
no setter
- canvasHeight → double?
-
no setter
- canvasWidth → double?
-
no setter
- currentPath → Path
-
no setter
-
currentStroke
→ List<
Offset> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasPanned → bool
-
no setter
- hasStrokes → bool
-
no setter
- imageHeight → double?
-
no setter
- imageWidth → double?
-
no setter
- isDrawing → bool
-
no setter
- isLoading → bool
-
no setter
- maskColor → Color
-
no setter
- maxBrushSize → double
-
no setter
- minBrushSize → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
strokes
→ List<
DrawingStroke> -
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clear(
) → void -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
loadBackgroundImage(
XFile backgroundImage) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
onPanEnd(
DragEndDetails details) → void -
onPanStart(
DragStartDetails details) → void -
onPanUpdate(
DragUpdateDetails details) → void -
onTapDown(
TapDownDetails details) → void -
onTapUp(
TapUpDetails details) → void -
redo(
) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
saveMask(
) → Future< XFile?> -
setBrushSize(
double size) → void -
setCanvasDimensions(
double width, double height) → void -
setOnMaskSaved(
dynamic callback(XFile)?) → void -
toString(
) → String -
A string representation of this object.
inherited
-
undo(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited